translate.convert.tiki2po.tiki2po

Package translate :: Package convert :: Module tiki2po :: Class tiki2po |
[hide private]
[frames] | no frames]

# Class tiki2po

source code

Instance Methods | [hide private]
__init__(self, includeunused=False) | source code
convertstore(self, thetikifile) Converts a given (parsed) tiki file to a po file. | source code

Method Details | [hide private]

### __init__(self, includeunused=False) (Constructor) | source code
Parameters: `includeunused` - On conversion, should the "unused" section be preserved? Default: False

### convertstore(self, thetikifile) | source code
Converts a given (parsed) tiki file to a po file. Parameters: `thetikifile` - a tikifile pre-loaded with input data